==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Point central</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Point de référence</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--google--
Indiquer le point cible</translatorcomment>
        <translation>Point cible</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Rotation</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Options de rotation</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Nombre de copies</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Supprimer original</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;Garder original</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>Copies &amp;multiples</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Angle (a) :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Utiliser calque et &amp;attributs actuel</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Point central</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Point de référence</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--google--
Indiquer le point cible</translatorcomment>
        <translation>Point cible</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Rotation</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Options de rotation</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Nombre de copies</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Supprimer original</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;Garder original</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>Copies &amp;multiples</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;Angle (a) :</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Define angle using mouse cursor</source>
        <translation>Définir l&apos;angle à l&apos;aide du curseur de la souris</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Utiliser calque et &amp;attributs actuel</translation>
    </message>
</context>
</TS>
